function bt_polyh_plotpt2 (obj,opt)
	% -- function for internal use
	%
	%    see also http://bensolve.org/files/manual.pdf
	
	% test: incdata has exactly 2 entries in each line
	dim=obj.dim-obj.lindim;
	if ~all(sum(obj.incdata.bit,2)==2)
		error('test of incidence list failed');
	end
	% determine indices of unbounded facets
	r=size(obj.vrepdata.V,2);
	s=size(obj.vrepdata.D,2);
	idx_ubf=find(any(obj.incdata.bit(:,r+1:r+s),2))';
	% test: unbounded facets must be incident to one direction and one vertex
	for i=1:length(idx_ubf)
		a=obj.incdata.list{idx_ubf(i)};
		if length(a) ~=2 || min(a)>r || max(a) <=r
			error('unexpected error');
		end
	end

	% insert new points (replacement of directions)
	obj.vrepdata.V=[obj.vrepdata.V, zeros(obj.sdim,length(idx_ubf))];
	obj.incdata.bit=[obj.incdata.bit(:,1:r),zeros(size(obj.incdata.bit,1),length(idx_ubf))];
	for i=1:length(idx_ubf)
		v=min(obj.incdata.list{idx_ubf(i)}(1,:));
		d=max(obj.incdata.list{idx_ubf(i)}(1,:));
		if v>r || d<=r
			error('unexpected error');
		end		
		dir=obj.vrepdata.D(:,d-r);
		vert=obj.vrepdata.V(:,v);
		obj.vrepdata.V(:,r+i)=opt.dirlength*bt_polyh_normed(dir)+vert;
		obj.incdata.bit(idx_ubf(i),r+i)=1;
	end
	
	% delete directions
	obj.vrepdata.D=zeros(obj.sdim,0);
	obj.adjdata.bit=~logical(obj.incdata.bit'*obj.incdata.bit-dim+1);
	for i=1:size(obj.adjdata.bit,2)
		obj.adjdata.bit(i,i)=0;
	end
	obj.incdata.list=bt_polyh_bit2cell(obj.incdata.bit);
	obj.adjdata.list=bt_polyh_bit2cell(obj.adjdata.bit);
	
	% bring vertices in correct order 
	t=size(obj.vrepdata.V,2);
	idx=zeros(1,t);
	bit=zeros(1,t);
	a=find(sum(obj.adjdata.bit,1)==1,1);
	if ~isempty(a)
		idx(1)=a;
	else
		idx(1)=1;
	end
	bit(idx(1))=1;
	for i=2:t;
		idx(i)=find(obj.adjdata.bit(idx(i-1),:) & ~bit,1);
		bit(idx(i))=1;
	end
	x=obj.vrepdata.V(:,idx)';
	y=obj.vrepdata.V(:,1:r)';
	
	warning('off'); %#ok
	clf
	hold on
	% plot interior
	if ~opt.graphmode
		if obj.sdim==2
			patch('XData',x(:,1),'YData',x(:,2),'facecolor',opt.color,'edgecolor',opt.color);
		else
			view ([4 -5 2]);
			patch('XData',x(:,1),'YData',x(:,2),'ZData',x(:,3),'facecolor',opt.color,'edgecolor',opt.color);
		end
	end
	% plot boundary
	for i=1:size(x,1)-1
		if obj.sdim==2
			line(x(i:i+1,1),x(i:i+1,2),'color',opt.edgecolor,'linewidth',opt.edgewidth);
		else
			line(x(i:i+1,1),x(i:i+1,2),x(i:i+1,3),'color',opt.edgecolor,'linewidth',opt.edgewidth);
		end
	end
	if idx(end)<=r && idx(1)<=r
		if obj.sdim==2
			line(x([1,end],1),x([1,end],2),'color',opt.edgecolor,'linewidth',opt.edgewidth);
		else
			line(x([1,end],1),x([1,end],2),x([1,end],3),'color',opt.edgecolor,'linewidth',opt.edgewidth);
		end
	end
	if opt.vertexsize2>0
		if obj.sdim==2
			scatter(y(:,1),y(:,2),opt.vertexsize2,[0 0 0],'filled');
		else
			scatter3(y(:,1),y(:,2),y(:,3),opt.vertexsize2,[0 0 0],'filled');
		end
	end	
	if obj.lindim==1
		x=(obj.vrepdata.V(:,1:r)+obj.vrepdata.L*ones(1,r));
		y=(obj.vrepdata.V(:,1:r)-obj.vrepdata.L*ones(1,r));
		for j=1:size(x,2)
			line([x(1,j),y(1,j)],[x(2,j),y(2,j)],[x(3,j),y(3,j)],'color',opt.linealityspacecolor,'linewidth',2);
		end	
	end
	
	hold off
end